==> volcengine-1.0.63.tar.gz: volcengine-1.0.63/volcengine/const/Const.py <==
# coding: utf-8

REGION_CN_NORTH1 = "cn-north-1"
REGION_US_EAST1 = "us-east-1"
REGION_AP_SINGAPORE1 = "ap-singapore-1"

INNER_REGION_CN_NORTH1 = "cn-north-1-inner"
INNER_REGION_US_EAST1 = "us-east-1-inner"
INNER_REGION_AP_SINGAPORE1 = "ap-singapore-1-inner"

HTTP = 'http'
HTTPS = 'https'

FILE_TYPE_VIDEO = 'video'
FILE_TYPE_MEDIA = 'media'
FILE_TYPE_IMAGE = 'image'
FILE_TYPE_OBJECT = 'object'

UPLOAD_FORMAT_MP4 = 'mp4'
UPLOAD_FORMAT_M3U8 = 'm3u8'

FORMAT_JPEG = 'jpeg'
FORMAT_PNG = 'png'
FORMAT_WEBP = 'webp'
FORMAT_AWEBP = 'awebp'
FORMAT_GIF = 'gif'
FORMAT_HEIC = 'heic'
FORMAT_ORIGINAL = 'image'

VOD_TPL_OBJ = 'tplv-vod-obj'
VOD_TPL_NOOP = 'tplv-vod-noop'
VOD_TPL_RESIZE = 'tplv-vod-rs'
VOD_TPL_CENTER_CROP = 'tplv-vod-cc'
VOD_TPL_SMART_CROP = 'tplv-vod-cs'
VOD_TPL_SIG = 'tplv-bd-sig'

LETTER_RUNES = 'abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ'

RESOURCE_SPACE_FORMAT = "trn:vod:%s:*:space/%s"
RESOURCE_VIDEO_FORMAT = 'trn:vod::*:video_id/%s'
RESOURCE_STREAM_TYPE_FORMAT = 'trn:vod:::stream_type/%s'
RESOURCE_WATERMARK_FORMAT = 'trn:vod::*:watermark/%s'

ACTION_VOD_GET_PLAY_INFO = "vod:GetPlayInfo"

STAR = '*'

CATEGORY_VIDEO = "video"
CATEGORY_AUDIO = "audio"
CATEGORY_IMAGE = "image"
CATEGORY_DYNAMICIMG = "dynamic_img"
CATEGORY_SUBTITLE = "subtitle"
CATEGORY_FONT = "font"

SMS_CHANNEL_TYPE_CN_OTP = "CN_OTP"
SMS_CHANNEL_TYPE_CN_NTC = "CN_NTC"
SMS_CHANNEL_TYPE_CN_MKT = "CN_MKT"
SMS_CHANNEL_TYPE_I18N_OTP = "I18N_OTP"
SMS_CHANNEL_TYPE_I18N_MKT = "I18N_MKT"

ENABLE_STATUS_NOT_ENABLE = "0"
ENABLE_STATUS_ENABLE = "1"

AREA_CN = "cn"
AREA_OVERSEAS = "overseas"
AREA_ALL = "all"

==> volcengine-1.0.77.tar.gz: volcengine-1.0.77/volcengine/const/Const.py <==
# coding: utf-8

REGION_CN_NORTH1 = "cn-north-1"
REGION_US_EAST1 = "us-east-1"
REGION_AP_SINGAPORE1 = "ap-singapore-1"

INNER_REGION_CN_NORTH1 = "cn-north-1-inner"
INNER_REGION_US_EAST1 = "us-east-1-inner"
INNER_REGION_AP_SINGAPORE1 = "ap-singapore-1-inner"

HTTP = 'http'
HTTPS = 'https'

FILE_TYPE_VIDEO = 'video'
FILE_TYPE_MEDIA = 'media'
FILE_TYPE_IMAGE = 'image'
FILE_TYPE_OBJECT = 'object'

UPLOAD_FORMAT_MP4 = 'mp4'
UPLOAD_FORMAT_M3U8 = 'm3u8'

FORMAT_JPEG = 'jpeg'
FORMAT_PNG = 'png'
FORMAT_WEBP = 'webp'
FORMAT_AWEBP = 'awebp'
FORMAT_GIF = 'gif'
FORMAT_HEIC = 'heic'
FORMAT_ORIGINAL = 'image'

VOD_TPL_OBJ = 'tplv-vod-obj'
VOD_TPL_NOOP = 'tplv-vod-noop'
VOD_TPL_RESIZE = 'tplv-vod-rs'
VOD_TPL_CENTER_CROP = 'tplv-vod-cc'
VOD_TPL_SMART_CROP = 'tplv-vod-cs'
VOD_TPL_SIG = 'tplv-bd-sig'

LETTER_RUNES = 'abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ'

RESOURCE_SPACE_FORMAT = "trn:vod:%s:*:space/%s"
RESOURCE_VIDEO_FORMAT = 'trn:vod::*:video_id/%s'
RESOURCE_STREAM_TYPE_FORMAT = 'trn:vod:::stream_type/%s'
RESOURCE_WATERMARK_FORMAT = 'trn:vod::*:watermark/%s'

ACTION_VOD_GET_PLAY_INFO = "vod:GetPlayInfo"

STAR = '*'

CATEGORY_VIDEO = "video"
CATEGORY_AUDIO = "audio"
CATEGORY_IMAGE = "image"
CATEGORY_DYNAMICIMG = "dynamic_img"
CATEGORY_SUBTITLE = "subtitle"
CATEGORY_FONT = "font"

SMS_CHANNEL_TYPE_CN_OTP = "CN_OTP"
SMS_CHANNEL_TYPE_CN_NTC = "CN_NTC"
SMS_CHANNEL_TYPE_CN_MKT = "CN_MKT"
SMS_CHANNEL_TYPE_I18N_OTP = "I18N_OTP"
SMS_CHANNEL_TYPE_I18N_MKT = "I18N_MKT"

ENABLE_STATUS_NOT_ENABLE = "0"
ENABLE_STATUS_ENABLE = "1"

AREA_CN = "cn"
AREA_OVERSEAS = "overseas"
AREA_ALL = "all"

SOURCE_TYPE_TEXT = "text/string"
SOURCE_TYPE_VIDEO = "video/mp4"
SOURCE_TYPE_IMAGE_JPG = "image/jpg"
Source_TYPE_IMAGE_PNG = "image/png "
Source_TYPE_IMAGE_GIF = "image/gif"
Source_TYPE_MP3 = "audio/mp3"

SourceTypeImageJPG = "image/jpg"
SourceTypeImagePNG = "image/png "
SourceTypeImageGIF = "image/gif"
SourceTypeAudio = "audio/mp3"
